@@ -80,8 +80,8 @@ class APIClient(object):
         rjson = response.json()
         return rjson
 
-    def get_results(self, studyid):
-        response = self.perform_request("Scores", {"studyid": studyid})
+    def get_results(self, studyid, question, email, imageid, caseid):
+        response = self.perform_request("Scores", {"studyid": studyid, "question": question, "email": email, "imageid": imageid, "caseid": caseid})
         rjson = response.json()
         return [SlideScoreResult(r) for r in rjson]
         
@@ -125,15 +125,20 @@ class APIClient(object):
         rjson = response.json()
         return ( self.end_point.replace("/Api/","/i/"+str(imageid)+"/"+rjson['urlPart']+"/_files"), rjson['cookiePart'] )
 
-    def getFilename(self, s):
+    def _get_filename(self, s):
       fname = re.findall("filename\*?=([^;]+)", s, flags=re.IGNORECASE)
       return fname[0].strip().strip('"')        
         
     def download_slide(self, studyid, imageid, filepath):
         response = self.perform_request("DownloadSlide", {"studyid": studyid, "imageid": imageid}, method="GET")
-        fname = self.getFilename(response.headers["Content-Disposition"])
+        fname = self._get_filename(response.headers["Content-Disposition"])
         with open(filepath+'/'+fname, 'wb') as f:
             for chunk in response.iter_content(chunk_size=8192): 
                 f.write(chunk)
 
-       
+    def get_screenshot_whole(self, imageid, user, question, output_file):
+        response = self.perform_request("GetScreenshot", {"imageid": imageid, "withAnnotationForUser": user, "question": question, "level": 11}, method="GET")
+        with open(output_file, 'wb') as f:
+            for chunk in response.iter_content(chunk_size=8192): 
+                f.write(chunk)
+
